# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`lvm`](#lvm): Manage LVM

### Defined types

* [`lvm::logical_volume`](#lvm--logical_volume): Manage a logical volume.
* [`lvm::physical_volume`](#lvm--physical_volume): Manage a physical volume
* [`lvm::volume`](#lvm--volume): Manage a logical_volume.
* [`lvm::volume_group`](#lvm--volume_group): Manage a volume group.

### Resource types

* [`filesystem`](#filesystem): The filesystem type
* [`logical_volume`](#logical_volume): Logical volume resource type
* [`physical_volume`](#physical_volume): Physical volume resource type
* [`volume_group`](#volume_group): Volume group resource type

### Functions

* [`lvm::bytes_to_size`](#lvm--bytes_to_size): Convert a number of bytes to a size format that LVM can understand
* [`lvm::size_to_bytes`](#lvm--size_to_bytes): Convert an LVM size to bytes, the opposite of `lvm::bytes_to_size`

### Tasks

* [`ensure_fs`](#ensure_fs): Ensures settings on a filesystem using the type & provider
* [`ensure_lv`](#ensure_lv): Ensures settings on a logical volume using the type & provider
* [`ensure_pv`](#ensure_pv): Ensures settings on a physical volumes using the type & provider
* [`ensure_vg`](#ensure_vg): Ensures settings on a volume group using the type & provider
* [`extend_lv`](#extend_lv): Extends a logical volume
* [`extend_vg`](#extend_vg): Adds physical volumes to a volume group
* [`mount_lv`](#mount_lv): Mounts a logical volume

### Plans

* [`lvm::expand`](#lvm--expand): An opinionated method for expanding storage on machines that use LVM.
If this doesn't fit your needs, simply tie the tasks together in
some way that does.

## Classes

### <a name="lvm"></a>`lvm`

Manage LVM

#### Parameters

The following parameters are available in the `lvm` class:

* [`package_ensure`](#-lvm--package_ensure)
* [`manage_pkg`](#-lvm--manage_pkg)
* [`volume_groups`](#-lvm--volume_groups)

##### <a name="-lvm--package_ensure"></a>`package_ensure`

Data type: `Enum['installed', 'present', 'latest', 'absent']`

Ensure value for the lvm2 package.

Default value: `'installed'`

##### <a name="-lvm--manage_pkg"></a>`manage_pkg`

Data type: `Boolean`

Whether to manage the lvm2 package.

Default value: `false`

##### <a name="-lvm--volume_groups"></a>`volume_groups`

Data type: `Hash`

Hash of lvm::volume_group resources to create.

Default value: `{}`

## Defined types

### <a name="lvm--logical_volume"></a>`lvm::logical_volume`

This will automatically set this volume group as a dependency,
but it must be defined elsewhere using the volume_group resource type.

the partition size.

(if the LV found is larger then the size requests this is just logged not causing a FAIL)

are in sync. Cannot be changed on already mirrored volume.
Take your mirror size in terabytes and round up that number to the next power of 2, using that number as the -R argument

#### Parameters

The following parameters are available in the `lvm::logical_volume` defined type:

* [`volume_group`](#-lvm--logical_volume--volume_group)
* [`size`](#-lvm--logical_volume--size)
* [`initial_size`](#-lvm--logical_volume--initial_size)
* [`ensure`](#-lvm--logical_volume--ensure)
* [`options`](#-lvm--logical_volume--options)
* [`pass`](#-lvm--logical_volume--pass)
* [`dump`](#-lvm--logical_volume--dump)
* [`fs_type`](#-lvm--logical_volume--fs_type)
* [`mkfs_options`](#-lvm--logical_volume--mkfs_options)
* [`mountpath`](#-lvm--logical_volume--mountpath)
* [`mountpath_require`](#-lvm--logical_volume--mountpath_require)
* [`mounted`](#-lvm--logical_volume--mounted)
* [`createfs`](#-lvm--logical_volume--createfs)
* [`extents`](#-lvm--logical_volume--extents)
* [`stripes`](#-lvm--logical_volume--stripes)
* [`stripesize`](#-lvm--logical_volume--stripesize)
* [`readahead`](#-lvm--logical_volume--readahead)
* [`range`](#-lvm--logical_volume--range)
* [`size_is_minsize`](#-lvm--logical_volume--size_is_minsize)
* [`type`](#-lvm--logical_volume--type)
* [`thinpool`](#-lvm--logical_volume--thinpool)
* [`poolmetadatasize`](#-lvm--logical_volume--poolmetadatasize)
* [`mirror`](#-lvm--logical_volume--mirror)
* [`mirrorlog`](#-lvm--logical_volume--mirrorlog)
* [`no_sync`](#-lvm--logical_volume--no_sync)
* [`region_size`](#-lvm--logical_volume--region_size)
* [`alloc`](#-lvm--logical_volume--alloc)
* [`yes_flag`](#-lvm--logical_volume--yes_flag)

##### <a name="-lvm--logical_volume--volume_group"></a>`volume_group`

Data type: `String[1]`

The volume group name associated with this logical volume.

##### <a name="-lvm--logical_volume--size"></a>`size`

Data type: `Optional[String[1]]`

Configures the size of the filesystem. Supports filesystem resizing. The size will be rounded up to the nearest multiple of

Default value: `undef`

##### <a name="-lvm--logical_volume--initial_size"></a>`initial_size`

Data type: `Optional[String[1]]`

The initial size of the logical volume. This will only apply to newly-created volumes

Default value: `undef`

##### <a name="-lvm--logical_volume--ensure"></a>`ensure`

Data type: `Enum['absent', 'present']`



Default value: `present`

##### <a name="-lvm--logical_volume--options"></a>`options`

Data type: `String[1]`

Params for the mkfs command

Default value: `'defaults'`

##### <a name="-lvm--logical_volume--pass"></a>`pass`

Data type: `Variant[String[1], Integer]`



Default value: `'2'`

##### <a name="-lvm--logical_volume--dump"></a>`dump`

Data type: `Variant[String[1], Integer]`



Default value: `'0'`

##### <a name="-lvm--logical_volume--fs_type"></a>`fs_type`

Data type: `String[1]`

The file system type. eg. ext3.

Default value: `'ext4'`

##### <a name="-lvm--logical_volume--mkfs_options"></a>`mkfs_options`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-lvm--logical_volume--mountpath"></a>`mountpath`

Data type: `Stdlib::Absolutepath`



Default value: `"/${name}"`

##### <a name="-lvm--logical_volume--mountpath_require"></a>`mountpath_require`

Data type: `Boolean`



Default value: `false`

##### <a name="-lvm--logical_volume--mounted"></a>`mounted`

Data type: `Boolean`

If puppet should mount the volume. This only affects what puppet will do, and not what will be mounted at boot-time.

Default value: `true`

##### <a name="-lvm--logical_volume--createfs"></a>`createfs`

Data type: `Boolean`



Default value: `true`

##### <a name="-lvm--logical_volume--extents"></a>`extents`

Data type: `Optional[String[1]]`

The number of logical extents to allocate for the new logical volume. Set to undef to use all available space

Default value: `undef`

##### <a name="-lvm--logical_volume--stripes"></a>`stripes`

Data type: `Optional[Variant[String[1], Integer]]`

The number of stripes to allocate for the new logical volume.

Default value: `undef`

##### <a name="-lvm--logical_volume--stripesize"></a>`stripesize`

Data type: `Optional[Variant[String[1], Integer]]`

The stripesize to use for the new logical volume.

Default value: `undef`

##### <a name="-lvm--logical_volume--readahead"></a>`readahead`

Data type: `Optional[Variant[String[1], Integer]]`

The readahead count to use for the new logical volume.

Default value: `undef`

##### <a name="-lvm--logical_volume--range"></a>`range`

Data type: `Optional[Enum['maximum', 'minimum']]`

- Set to true if the ‘size’ parameter specified, is just the minimum size you need

Default value: `undef`

##### <a name="-lvm--logical_volume--size_is_minsize"></a>`size_is_minsize`

Data type: `Optional[Boolean]`

Lists strings for access control for connection method, users, databases, IPv4 addresses;

Default value: `undef`

##### <a name="-lvm--logical_volume--type"></a>`type`

Data type: `Optional[String[1]]`

Configures the logical volume type. AIX only

Default value: `undef`

##### <a name="-lvm--logical_volume--thinpool"></a>`thinpool`

Data type: `Variant[Boolean, String]`

- Set to true to create a thin pool or to pool name to create thin volume

Default value: `false`

##### <a name="-lvm--logical_volume--poolmetadatasize"></a>`poolmetadatasize`

Data type: `Optional[Integer[0, 4]]`

Set the initial size of the logical volume pool metadata on creation

Default value: `undef`

##### <a name="-lvm--logical_volume--mirror"></a>`mirror`

Data type: `Optional[String[1]]`

The number of mirrors of the volume.

Default value: `undef`

##### <a name="-lvm--logical_volume--mirrorlog"></a>`mirrorlog`

Data type: `Optional[Enum['core', 'disk', 'mirrored']]`

How to store the mirror log (Allowed values: core, disk, mirrored).

Default value: `undef`

##### <a name="-lvm--logical_volume--no_sync"></a>`no_sync`

Data type: `Optional[Boolean]`

An optimization in lvcreate, at least on Linux.

Default value: `undef`

##### <a name="-lvm--logical_volume--region_size"></a>`region_size`

Data type: `Optional[Variant[String[1], Integer]]`

A mirror is divided into regions of this size (in MB), the mirror log uses this granularity to track which regions

Default value: `undef`

##### <a name="-lvm--logical_volume--alloc"></a>`alloc`

Data type: `Optional[Enum['anywhere', 'contiguous', 'cling', 'inherit', 'normal']]`

The allocation policy when a command needs to allocate Physical Extents from the Volume Group.

Default value: `undef`

##### <a name="-lvm--logical_volume--yes_flag"></a>`yes_flag`

Data type: `Boolean`

If set to true, do not prompt for confirmation interactively but always assume the answer yes.

Default value: `false`

### <a name="lvm--physical_volume"></a>`lvm::physical_volume`

Manage a physical volume

#### Parameters

The following parameters are available in the `lvm::physical_volume` defined type:

* [`ensure`](#-lvm--physical_volume--ensure)
* [`force`](#-lvm--physical_volume--force)
* [`unless_vg`](#-lvm--physical_volume--unless_vg)

##### <a name="-lvm--physical_volume--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

ensures phycial volume is present or absent

Default value: `present`

##### <a name="-lvm--physical_volume--force"></a>`force`

Data type: `Boolean`

Whether to force the creation without any confirmation.

Default value: `false`

##### <a name="-lvm--physical_volume--unless_vg"></a>`unless_vg`

Data type: `Optional[String[1]]`

Do not do anything if the VG already exists. The value should be the name of the volume group to check for.

Default value: `undef`

### <a name="lvm--volume"></a>`lvm::volume`

Ensures a physical_volume, volume_group, and filesystem resource
have been created on the block device supplied in the pv parameter.

physical_volume, volume_group,
logical_volume, and filesystem resources are
present for the volume. A value of cleaned will ensure that all
of the resources are absent. Warning: this has a high potential
for unexpected harm, so use it with caution. A value of absent
will remove only the logical_volume resource from the system.

volume.

Set to undef to use all available space

This will only apply to newly-created volumes

#### Examples

##### Basic usage

```puppet

lvm::volume { 'lv_example0':
  vg     => 'vg_example0',
  pv     => '/dev/sdd1',
  fstype => 'ext4',
  size   => '100GB',
}
```

#### Parameters

The following parameters are available in the `lvm::volume` defined type:

* [`ensure`](#-lvm--volume--ensure)
* [`fstype`](#-lvm--volume--fstype)
* [`pv`](#-lvm--volume--pv)
* [`vg`](#-lvm--volume--vg)
* [`size`](#-lvm--volume--size)
* [`extents`](#-lvm--volume--extents)
* [`initial_size`](#-lvm--volume--initial_size)

##### <a name="-lvm--volume--ensure"></a>`ensure`

Data type: `Enum['present', 'absent', 'cleaned']`

Can only be set to cleaned, absent or present. A value of present will ensure that the

##### <a name="-lvm--volume--fstype"></a>`fstype`

Data type: `Optional[String[1]]`

The type of filesystem to create on the logical

Default value: `undef`

##### <a name="-lvm--volume--pv"></a>`pv`

Data type: `Stdlib::Absolutepath`

path to physcial volume

##### <a name="-lvm--volume--vg"></a>`vg`

Data type: `String[1]`

value of volume group

##### <a name="-lvm--volume--size"></a>`size`

Data type: `Optional[String[1]]`

The size the logical_voluem should be.

Default value: `undef`

##### <a name="-lvm--volume--extents"></a>`extents`

Data type: `Optional[Variant[String[1], Integer]]`

The number of logical extents to allocate for the new logical volume.

Default value: `undef`

##### <a name="-lvm--volume--initial_size"></a>`initial_size`

Data type: `Optional[String[1]]`

The initial size of the logical volume.

Default value: `undef`

### <a name="lvm--volume_group"></a>`lvm::volume_group`

Manage a volume group.

#### Parameters

The following parameters are available in the `lvm::volume_group` defined type:

* [`physical_volumes`](#-lvm--volume_group--physical_volumes)
* [`createonly`](#-lvm--volume_group--createonly)
* [`ensure`](#-lvm--volume_group--ensure)
* [`logical_volumes`](#-lvm--volume_group--logical_volumes)
* [`followsymlinks`](#-lvm--volume_group--followsymlinks)

##### <a name="-lvm--volume_group--physical_volumes"></a>`physical_volumes`

Data type: `Variant[Hash, Array, String]`

The list of physical volumes to be included in the volume group.
This will automatically set these as dependencies, but they must
be defined elsewhere using the physical_volume resource type.

##### <a name="-lvm--volume_group--createonly"></a>`createonly`

Data type: `Boolean`

If true, the volume group will be created if it does not exist. If
the volume group does exist, no action will be taken.

Default value: `false`

##### <a name="-lvm--volume_group--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Whether this volume group should be present or absent.

Default value: `present`

##### <a name="-lvm--volume_group--logical_volumes"></a>`logical_volumes`

Data type: `Hash`

A hash of lvm::logical_volume resources to create in this volume
group.

Default value: `{}`

##### <a name="-lvm--volume_group--followsymlinks"></a>`followsymlinks`

Data type: `Boolean`

If true, all current and wanted values of the physical_volumes
property will be followed to their real files on disk if they are
in fact symlinks. This is useful to have Puppet determine what the
actual PV device is if the property value is a symlink, like
`/dev/disk/by-path/xxxx -> ../../sda`.

Default value: `false`

## Resource types

### <a name="filesystem"></a>`filesystem`

The filesystem type

#### Properties

The following properties are available in the `filesystem` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `size`

Configures the size of the filesystem.  Supports filesystem resizing.  The size will be rounded up to the nearest multiple of the partition size. AIX only.

#### Parameters

The following parameters are available in the `filesystem` type.

* [`accounting`](#-filesystem--accounting)
* [`ag_size`](#-filesystem--ag_size)
* [`agblksize`](#-filesystem--agblksize)
* [`atboot`](#-filesystem--atboot)
* [`compress`](#-filesystem--compress)
* [`device`](#-filesystem--device)
* [`encrypted`](#-filesystem--encrypted)
* [`extended_attributes`](#-filesystem--extended_attributes)
* [`frag`](#-filesystem--frag)
* [`fs_type`](#-filesystem--fs_type)
* [`initial_size`](#-filesystem--initial_size)
* [`isnapshot`](#-filesystem--isnapshot)
* [`large_files`](#-filesystem--large_files)
* [`log_partitions`](#-filesystem--log_partitions)
* [`logname`](#-filesystem--logname)
* [`logsize`](#-filesystem--logsize)
* [`maxext`](#-filesystem--maxext)
* [`mkfs_cmd`](#-filesystem--mkfs_cmd)
* [`mount_options`](#-filesystem--mount_options)
* [`mountgroup`](#-filesystem--mountgroup)
* [`mountguard`](#-filesystem--mountguard)
* [`name`](#-filesystem--name)
* [`nbpi`](#-filesystem--nbpi)
* [`nodename`](#-filesystem--nodename)
* [`options`](#-filesystem--options)
* [`perms`](#-filesystem--perms)
* [`provider`](#-filesystem--provider)
* [`vix`](#-filesystem--vix)
* [`volume_group`](#-filesystem--volume_group)

##### <a name="-filesystem--accounting"></a>`accounting`

Valid values: `true`, `false`

Specify accounting subsystem support, AIX only

##### <a name="-filesystem--ag_size"></a>`ag_size`

Valid values: `%r{\d+}`

Specify the allocation group size in megabytes, AIX only.

##### <a name="-filesystem--agblksize"></a>`agblksize`

Valid values: `%r{\d+}`

JFS2 block size in bytes, AIX only.

##### <a name="-filesystem--atboot"></a>`atboot`

Valid values: `true`, `false`

Specify whether the file system is mounted at boot time, AIX only

##### <a name="-filesystem--compress"></a>`compress`

Valid values: `LG`, `no`

Data compression, LZ or no. AIX only

##### <a name="-filesystem--device"></a>`device`

Device to create the filesystem on, this can be a device or a logical volume. AIX only

##### <a name="-filesystem--encrypted"></a>`encrypted`

Valid values: `true`, `false`

Specify and encrypted filesystem. AIX only

##### <a name="-filesystem--extended_attributes"></a>`extended_attributes`

Valid values: `v1`, `v2`

Format to be used to store extended attributes. AIX only

##### <a name="-filesystem--frag"></a>`frag`

Valid values: `%r{\d+}`

JFS fragment size in bytes. AIX only

##### <a name="-filesystem--fs_type"></a>`fs_type`

The file system type. eg. ext3.

##### <a name="-filesystem--initial_size"></a>`initial_size`

Initial size of the filesystem, Used only for resource creation, when using this option Puppet will not manage or
maintain the size. To resize filesystems see the size property. AIX only.

##### <a name="-filesystem--isnapshot"></a>`isnapshot`

Valid values: `true`, `false`

Specify whether the filesystem supports internal snapshots, AIX only

##### <a name="-filesystem--large_files"></a>`large_files`

Valid values: `true`, `false`

Large file enabled file system.  AIX only

##### <a name="-filesystem--log_partitions"></a>`log_partitions`

Specify the size of the log logical volume as number of logical partitions, AIX only

##### <a name="-filesystem--logname"></a>`logname`

Configure the log logical volume. AIX only

##### <a name="-filesystem--logsize"></a>`logsize`

Valid values: `%r{\d+}`

Size for an inline log in MB, AIX only

##### <a name="-filesystem--maxext"></a>`maxext`

Valid values: `%r{\d+}`

Size of a file extent in file system blocks, AIX only

##### <a name="-filesystem--mkfs_cmd"></a>`mkfs_cmd`

Command to use to create the file system. Defaults to mkswap for fs_type=swap, otherwise mkfs.{{fs_type}}

##### <a name="-filesystem--mount_options"></a>`mount_options`

Specify the options to be passed to the mount command. AIX only

##### <a name="-filesystem--mountgroup"></a>`mountgroup`

Mount group for the filesystem, AIX only

##### <a name="-filesystem--mountguard"></a>`mountguard`

Valid values: `true`, `false`

Enable the mountguard. AIX only

##### <a name="-filesystem--name"></a>`name`

namevar

Resource name

##### <a name="-filesystem--nbpi"></a>`nbpi`

Valid values: `%r{\d+}`

Bytes per inode. AIX only

##### <a name="-filesystem--nodename"></a>`nodename`

Specify the remote host where the filesystem resides. AIX only

##### <a name="-filesystem--options"></a>`options`

Params for the mkfs command. eg. -l internal,agcount=x

##### <a name="-filesystem--perms"></a>`perms`

Valid values: `ro`, `rw`

Permissions for the filesystem, AIX only

##### <a name="-filesystem--provider"></a>`provider`

The specific backend to use for this `filesystem` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### <a name="-filesystem--vix"></a>`vix`

Valid values: `true`, `false`

Specify that the file system can allocate inode extents smaller than the default, AIX only

##### <a name="-filesystem--volume_group"></a>`volume_group`

Volume group that the file system should be created on. AIX only.

### <a name="logical_volume"></a>`logical_volume`

Logical volume resource type

#### Properties

The following properties are available in the `logical_volume` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `mirror`

The number of mirrors of the volume.

##### `mirrorlog`

Valid values: `core`, `disk`, `mirrored`

How to store the mirror log (core, disk, mirrored).

##### `size`

The size of the logical volume. Set to undef to use all available space

##### `stripes`

The number of stripes to allocate for the new logical volume.

##### `volume_group`

The volume group name associated with this logical volume.  This will automatically
set this volume group as a dependency, but it must be defined elsewhere using the
volume_group resource type.

#### Parameters

The following parameters are available in the `logical_volume` type.

* [`alloc`](#-logical_volume--alloc)
* [`extents`](#-logical_volume--extents)
* [`initial_size`](#-logical_volume--initial_size)
* [`minor`](#-logical_volume--minor)
* [`name`](#-logical_volume--name)
* [`no_sync`](#-logical_volume--no_sync)
* [`persistent`](#-logical_volume--persistent)
* [`poolmetadatasize`](#-logical_volume--poolmetadatasize)
* [`provider`](#-logical_volume--provider)
* [`range`](#-logical_volume--range)
* [`readahead`](#-logical_volume--readahead)
* [`region_size`](#-logical_volume--region_size)
* [`resize_fs`](#-logical_volume--resize_fs)
* [`size_is_minsize`](#-logical_volume--size_is_minsize)
* [`stripesize`](#-logical_volume--stripesize)
* [`thinpool`](#-logical_volume--thinpool)
* [`type`](#-logical_volume--type)
* [`yes_flag`](#-logical_volume--yes_flag)

##### <a name="-logical_volume--alloc"></a>`alloc`

Valid values: `anywhere`, `contiguous`, `cling`, `inherit`, `normal`

Selects the allocation policy when a command needs to allocate Physical Extents from the Volume Group.

##### <a name="-logical_volume--extents"></a>`extents`

The number of logical extents to allocate for the new logical volume. Set to undef to use all available space

##### <a name="-logical_volume--initial_size"></a>`initial_size`

The initial size of the logical volume. This will only apply to newly-created volumes

##### <a name="-logical_volume--minor"></a>`minor`

Set the minor number

##### <a name="-logical_volume--name"></a>`name`

namevar

The name of the logical volume.  This is the unqualified name and will be
automatically added to the volume group's device path (e.g., '/dev/$vg/$lv').

##### <a name="-logical_volume--no_sync"></a>`no_sync`

An optimization in lvcreate, at least on Linux.

##### <a name="-logical_volume--persistent"></a>`persistent`

Set to true to make the block device persistent

##### <a name="-logical_volume--poolmetadatasize"></a>`poolmetadatasize`

Change the size of logical volume pool metadata

##### <a name="-logical_volume--provider"></a>`provider`

The specific backend to use for this `logical_volume` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-logical_volume--range"></a>`range`

Sets the inter-physical volume allocation policy. AIX only

##### <a name="-logical_volume--readahead"></a>`readahead`

The readahead count to use for the new logical volume.

##### <a name="-logical_volume--region_size"></a>`region_size`

A mirror is divided into regions of this size (in MB), the mirror log uses this granularity to track which regions are
in sync. CAN NOT BE CHANGED on already mirrored volume. Take your mirror size in terabytes and round up that number to
the next power of 2, using that number as the -R argument.

##### <a name="-logical_volume--resize_fs"></a>`resize_fs`

Whether or not to resize the underlying filesystem when resizing the logical volume.

Default value: `true`

##### <a name="-logical_volume--size_is_minsize"></a>`size_is_minsize`

Set to true if the 'size' parameter specified, is just the
minimum size you need (if the LV found is larger then the size requests
this is just logged not causing a FAIL)

Default value: `false`

##### <a name="-logical_volume--stripesize"></a>`stripesize`

The stripesize to use for the new logical volume.

##### <a name="-logical_volume--thinpool"></a>`thinpool`

Set to true to create a thin pool or to pool name to create thin volume

Default value: `false`

##### <a name="-logical_volume--type"></a>`type`

Configures the logical volume type.

##### <a name="-logical_volume--yes_flag"></a>`yes_flag`

If set to true, do not prompt for confirmation interactively but always assume the answer yes.

Default value: `false`

### <a name="physical_volume"></a>`physical_volume`

Physical volume resource type

#### Properties

The following properties are available in the `physical_volume` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `physical_volume` type.

* [`force`](#-physical_volume--force)
* [`name`](#-physical_volume--name)
* [`provider`](#-physical_volume--provider)
* [`unless_vg`](#-physical_volume--unless_vg)

##### <a name="-physical_volume--force"></a>`force`

Valid values: `true`, `false`

Force the creation without any confirmation.

Default value: `false`

##### <a name="-physical_volume--name"></a>`name`

namevar

Resource name

##### <a name="-physical_volume--provider"></a>`provider`

The specific backend to use for this `physical_volume` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-physical_volume--unless_vg"></a>`unless_vg`

Do not do anything if the VG already exists.  The value should be the
name of the volume group to check for.

### <a name="volume_group"></a>`volume_group`

Volume group resource type

#### Properties

The following properties are available in the `volume_group` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `physical_volumes`

The list of physical volumes to be included in the volume group; this
will automatically set these as dependencies, but they must be defined elsewhere
using the physical_volume resource type.

#### Parameters

The following parameters are available in the `volume_group` type.

* [`createonly`](#-volume_group--createonly)
* [`extent_size`](#-volume_group--extent_size)
* [`followsymlinks`](#-volume_group--followsymlinks)
* [`name`](#-volume_group--name)
* [`provider`](#-volume_group--provider)

##### <a name="-volume_group--createonly"></a>`createonly`

Valid values: `true`, `false`, `yes`, `no`

Aliases: `"yes"=>"true", "no"=>"false"`

If set to true the volume group will be created if it does not exist. If the
volume group does exist no action will be taken. Defaults to `false`.

Default value: `false`

##### <a name="-volume_group--extent_size"></a>`extent_size`

The physical extent size. Uses OS default if not provided. Only applicable on Linux.

##### <a name="-volume_group--followsymlinks"></a>`followsymlinks`

Valid values: `true`, `false`, `yes`, `no`

Aliases: `"yes"=>"true", "no"=>"false"`

If set to true all current and wanted values of the physical_volumes property
will be followed to their real files on disk if they are in fact symlinks. This is
useful to have Puppet determine what the actual PV device is if the property value
is a symlink, like '/dev/disk/by-path/xxxx -> ../../sda'. Defaults to `False`.

Default value: `false`

##### <a name="-volume_group--name"></a>`name`

namevar

The name of the volume group.

##### <a name="-volume_group--provider"></a>`provider`

The specific backend to use for this `volume_group` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

## Functions

### <a name="lvm--bytes_to_size"></a>`lvm::bytes_to_size`

Type: Puppet Language

Convert a number of bytes to a size format that LVM can understand

#### Examples

##### Return `200g`

```puppet

lvm::bytes_to_size(214748364800)
```

#### `lvm::bytes_to_size(Numeric $size)`

The lvm::bytes_to_size function.

Returns: `Any` LVM-formatted size

##### Examples

###### Return `200g`

```puppet

lvm::bytes_to_size(214748364800)
```

##### `size`

Data type: `Numeric`



### <a name="lvm--size_to_bytes"></a>`lvm::size_to_bytes`

Type: Puppet Language

Convert an LVM size to bytes, the opposite of `lvm::bytes_to_size`

#### `lvm::size_to_bytes(String $size)`

The lvm::size_to_bytes function.

Returns: `Any` byte value of LVM-formatted size

##### `size`

Data type: `String`



## Tasks

### <a name="ensure_fs"></a>`ensure_fs`

Ensures settings on a filesystem using the type & provider

**Supports noop?** false

#### Parameters

##### `fs_type`

Data type: `String`

The file system type. eg. ext3.

##### `name`

Data type: `String`

Fully qualified name

##### `mkfs_cmd`

Data type: `Optional[String]`

Command to use to create the file system. Defaults to mkswap for fs_type=swap, otherwise mkfs.{{fs_type}}

##### `options`

Data type: `Optional[String]`

Params for the mkfs command. eg. -l internal,agcount=x

##### `initial_size`

Data type: `Optional[String]`

Initial size of the filesystem, Used only for resource creation, when using this option Puppet will not manage or maintain the size. To resize filesystems see the size property. AIX only.

##### `size`

Data type: `Optional[String]`

Configures the size of the filesystem.  Supports filesystem resizing.  The size will be rounded up to the nearest multiple of the partition size. AIX only.

##### `ag_size`

Data type: `Optional[Integer]`

Specify the allocation group size in megabytes, AIX only.

##### `large_files`

Data type: `Optional[Boolean]`

Large file enabled file system.  AIX only

##### `compress`

Data type: `Optional[Enum[LG,no]]`

Data compression, LZ or no. AIX only

##### `frag`

Data type: `Optional[Integer]`

JFS fragment size in bytes. AIX only

##### `nbpi`

Data type: `Optional[Integer]`

Bytes per inode. AIX only

##### `logname`

Data type: `Optional[String]`

Configure the log logical volume. AIX only

##### `logsize`

Data type: `Optional[Integer]`

Size for an inline log in MB, AIX only

##### `maxext`

Data type: `Optional[Integer]`

Size of a file extent in file system blocks, AIX only

##### `mountguard`

Data type: `Optional[Boolean]`

Enable the mountguard. AIX only

##### `agblksize`

Data type: `Optional[Integer]`

JFS2 block size in bytes, AIX only

##### `extended_attributes`

Data type: `Optional[Enum[v1,v2]]`

Format to be used to store extended attributes. AIX only

##### `encrypted`

Data type: `Optional[Boolean]`

Specify and encrypted filesystem. AIX only

##### `isnapshot`

Data type: `Optional[Boolean]`

Specify whether the filesystem supports internal snapshots, AIX only

##### `mount_options`

Data type: `Optional[String]`

Specify the options to be passed to the mount command. AIX only

##### `vix`

Data type: `Optional[Boolean]`

Specify that the file system can allocate inode extents smaller than the default, AIX only

##### `log_partitions`

Data type: `Optional[String]`

Specify the size of the log logical volume as number of logical partitions, AIX only

##### `nodename`

Data type: `Optional[String]`

Specify the remote host where the filesystem resides. AIX only

##### `accounting`

Data type: `Optional[Boolean]`

Specify accounting subsystem support, AIX only

##### `mountgroup`

Data type: `Optional[String]`

Mount group for the filesystem, AIX only

##### `atboot`

Data type: `Optional[Boolean]`

Specify whether the file system is mounted at boot time, AIX only

##### `perms`

Data type: `Optional[Enum[ro,rw]]`

Permissions for the filesystem, AIX only

##### `device`

Data type: `Optional[String]`

Device to create the filesystem on, this can be a device or a logical volume. AIX only

##### `volume_group`

Data type: `Optional[String]`

Volume group that the file system should be created on. AIX only.

### <a name="ensure_lv"></a>`ensure_lv`

Ensures settings on a logical volume using the type & provider

**Supports noop?** false

#### Parameters

##### `ensure`

Data type: `Enum[present,absent]`

Present or absent

##### `name`

Data type: `String[1]`

The name of the logical volume.  This is the unqualified name and will be automatically added to the volume group's device path (e.g., '/dev/$vg/$lv').

##### `volume_group`

Data type: `Optional[String[1]]`

The volume group name associated with this logical volume

##### `size`

Data type: `Optional[Pattern[/^[0-9]+(\.[0-9]+)?[KMGTPEkmgtpe]/]]`

The size of the logical volume. Set to undef to use all available space

##### `extents`

Data type: `Optional[Pattern[/^\d+(%(?:vg|pvs|free|origin)?)?$/]]`

The number of logical extents to allocate for the new logical volume. Set to undef to use all available space

##### `persistent`

Data type: `Optional[Boolean]`

Set to true to make the block device persistent

##### `thinpool`

Data type: `Optional[Boolean]`

Set to true to create a thin pool or to pool name to create thin volume

##### `poolmetadatasize`

Data type: `Optional[Pattern[/^[0-9]+(\.[0-9]+)?[KMGTPEkmgtpe]/]]`

Change the size of logical volume pool metadata

##### `minor`

Data type: `Optional[Integer[0,255]]`

Set the minor number

##### `type`

Data type: `Optional[String[1]]`

Configures the logical volume type

##### `range`

Data type: `Optional[Enum[maximum,minimum]]`

Sets the inter-physical volume allocation policy. AIX only

##### `stripes`

Data type: `Optional[Integer]`

The number of stripes to allocate for the new logical volume

##### `stripesize`

Data type: `Optional[Integer]`

The stripesize to use for the new logical volume

##### `readahead`

Data type: `Optional[String]`

The readahead count to use for the new logical volume

##### `resize_fs`

Data type: `Optional[Boolean]`

Whether or not to resize the underlying filesystem when resizing the logical volume

##### `mirror`

Data type: `Optional[Integer[0,4]]`

The number of mirrors of the volume

##### `mirrorlog`

Data type: `Optional[Enum[core,disk,mirrored]]`

How to store the mirror log

##### `alloc`

Data type: `Optional[Enum[anywhere,contiguous,cling,inherit,normal]]`

Selects the allocation policy when a command needs to allocate Physical Extents from the Volume Group

##### `no_sync`

Data type: ``

An optimization in lvcreate, at least on Linux

##### `region_size`

Data type: `Optional[Integer]`

A mirror is divided into regions of this size (in MB), the mirror log uses this granularity to track which regions are in sync. CAN NOT BE CHANGED on already mirrored volume. Take your mirror size in terabytes and round up that number to the next power of 2, using that number as the -R argument.

##### `yes_flag`

Data type: `Boolean`

If set to true, do not prompt for confirmation interactively but always assume the answer yes.

### <a name="ensure_pv"></a>`ensure_pv`

Ensures settings on a physical volumes using the type & provider

**Supports noop?** false

#### Parameters

##### `name`

Data type: `String[1]`

The name of the physical volume

##### `ensure`

Data type: `Enum[present,absent]`

Present or absent

##### `unless_vg`

Data type: `Optional[String]`

Do not do anything if the VG already exists.  The value should be the name of the volume group to check for.

##### `force`

Data type: `Optional[Boolean]`

Force the creation without any confirmation

### <a name="ensure_vg"></a>`ensure_vg`

Ensures settings on a volume group using the type & provider

**Supports noop?** false

#### Parameters

##### `name`

Data type: `String[1]`

The name of the volume group

##### `ensure`

Data type: `Enum[present,absent]`

Present or absent

##### `createonly`

Data type: `Optional[Boolean]`

If set to true the volume group will be created if it does not exist. If the volume group does exist no action will be taken

##### `followsymlinks`

Data type: `Optional[Boolean]`

If set to true all current and wanted values of the physical_volumes property will be followed to their real files on disk if they are in fact symlinks. This is useful to have Puppet determine what the actual PV device is if the property value is a symlink, like '/dev/disk/by-path/xxxx -> ../../sda'

##### `physical_volumes`

Data type: `Array[String]`

The list of physical volumes to be included in the volume group

### <a name="extend_lv"></a>`extend_lv`

Extends a logical volume

**Supports noop?** false

#### Parameters

##### `size`

Data type: `String[1]`

Intended size or 'full'

##### `logical_volume`

Data type: `String[1]`

Name of the logical volume to extend

##### `volume_group`

Data type: `String[1]`

Name of the volume group on which the logical volume resides

### <a name="extend_vg"></a>`extend_vg`

Adds physical volumes to a volume group

**Supports noop?** false

#### Parameters

##### `volume_group`

Data type: `String[1]`

The name of the volume group

##### `physical_volumes`

Data type: `Array[String]`

The list of physical volumes to be included in the volume group

### <a name="mount_lv"></a>`mount_lv`

Mounts a logical volume

**Supports noop?** false

#### Parameters

##### `volume_group`

Data type: `String[1]`

The name of the volume group

##### `logical_volume`

Data type: `String[1]`

The name of the logical_volume to mount

##### `mountpoint`

Data type: `String[1]`

Where to mount the logical volume

##### `fstype`

Data type: `String`

The mount type. Valid values depend on the operating system. This is a required option.

##### `options`

Data type: `Optional[String]`

A single string containing options for the mount, as they would appear in fstab on Linux. For many platforms this is a comma-delimited string

##### `atboot`

Data type: `Optional[Boolean]`

Whether to mount the mount at boot. Not all platforms support this.

##### `owner`

Data type: `Optional[String]`

Owner for the mountpoint

##### `group`

Data type: `Optional[String]`

Group for the mountpoint

##### `mode`

Data type: `Optional[String]`

Permissions for the mountpoint

## Plans

### <a name="lvm--expand"></a>`lvm::expand`

An opinionated method for expanding storage on machines that use LVM.
If this doesn't fit your needs, simply tie the tasks together in
some way that does.

#### Parameters

The following parameters are available in the `lvm::expand` plan:

* [`server`](#-lvm--expand--server)
* [`volume_group`](#-lvm--expand--volume_group)
* [`logical_volume`](#-lvm--expand--logical_volume)
* [`additional_size`](#-lvm--expand--additional_size)
* [`disks`](#-lvm--expand--disks)
* [`resize_fs`](#-lvm--expand--resize_fs)

##### <a name="-lvm--expand--server"></a>`server`

Data type: `String`

The target for the plan

##### <a name="-lvm--expand--volume_group"></a>`volume_group`

Data type: `String`

The volume group to which the logical volume belongs

##### <a name="-lvm--expand--logical_volume"></a>`logical_volume`

Data type: `String`

The logical volume which is to be expanded

##### <a name="-lvm--expand--additional_size"></a>`additional_size`

Data type: `String`

How much size to add to the LV. This should be
specified in LVM format i.e. "200m" or "2.5g"

##### <a name="-lvm--expand--disks"></a>`disks`

Data type: `Array[String]`

Any physical disks that should be added to the volume group as
part of the expand process

Default value: `[]`

##### <a name="-lvm--expand--resize_fs"></a>`resize_fs`

Data type: `Boolean`

Wheather or not to resize the filesystem

Default value: `true`

